@@ -5,6 +5,8 @@
 #' ties, it picks the first duplicate, as it is the one most likely
 #' to be valid and authentic, given practice effects.
 #'
+#' @details For the *easystats* equivalent, see:
+#' [datawizard::data_duplicated()].
 #' @param data The data frame.
 #' @param id The ID variable for which to check for duplicates.
 #' @keywords duplicates
@@ -23,6 +25,7 @@
 #' @importFrom dplyr mutate group_by group_by slice_min distinct %>% ungroup
 
 best_duplicate <- function(data, id) {
+  check_col_names(data, id)
 
   og.names <- names(data)
   dups <- data %>%
