@@ -4,12 +4,21 @@
 #' and format in publication-ready format. The 95% confidence interval
 #' is for the effect size, Cohen's d, both provided by the `effectsize` package.
 #'
-#' This function relies on the base R `t.test` function, which
+#' @details This function relies on the base R [t.test()] function, which
 #' uses the Welch t-test per default (see why here:
 #' \url{https://daniellakens.blogspot.com/2015/01/always-use-welchs-t-test-instead-of.html}).
 #' To use the Student t-test, simply add the following
 #' argument: `var.equal = TRUE`.
 #'
+#' Note that for paired *t* tests, you need to use `paired = TRUE`, and
+#' you also need data in "long" format rather than wide format (like for
+#' the `ToothGrowth` data set). In this case, the `group` argument refers
+#' to the participant ID for example, so the same group/participant is
+#' measured several times, and thus has several rows.
+#'
+#' For the *easystats* equivalent, use: [report::report()] on the
+#' [t.test()] object.
+#'
 #' @param data The data frame.
 #' @param response The dependent variable.
 #' @param correction What correction for multiple comparison
@@ -18,7 +27,7 @@
 #' @param group The group for the comparison.
 
 #' @param warning Whether to display the Welch test warning or not.
-#' @param ... Further arguments to be passed to the `t.test`
+#' @param ... Further arguments to be passed to the [t.test()]
 #' function (e.g., to use Student instead of Welch test, to
 #' change from two-tail to one-tail, or to do a paired-sample
 #' t-test instead of independent samples).
@@ -70,6 +79,7 @@
 #' )
 #'
 #' # Paired t-test instead of independent samples
+#' # Requires data in "long" format
 #' nice_t_test(
 #'   data = ToothGrowth,
 #'   response = "len",
@@ -88,6 +98,7 @@ nice_t_test <- function(data,
                         correction = "none",
                         warning = TRUE,
                         ...) {
+  check_col_names(data, c(group, response))
   rlang::check_installed(c("effectsize", "methods"),
                          reason = "for this function.")
   args <- list(...)
